@@ -185,7 +185,7 @@ class JABDriver(object):
             hwnd, byref(vmid), byref(accessible_context)
         )
         vmid = vmid.value
-        return (accessible_context, vmid)
+        return accessible_context, vmid
 
     def get_version_info(self) -> Dict[str, str]:
         """Gets the version information of the instance of Java Access Bridge instance your application is using.
@@ -234,8 +234,7 @@ class JABDriver(object):
         """
         start = time()
         while True:
-            hwnd = self.get_java_window_hwnd(title=title)
-            if hwnd:
+            if hwnd := self.get_java_window_hwnd(title=title):
                 return hwnd
             log_out = f"no java window found by title '{title}'"
             if self.latest_log != log_out:
@@ -259,6 +258,15 @@ class JABDriver(object):
         else:
             return self.root_element.find_element_by_name(value=value, visible=visible)
 
+    def find_element_by_description(self, value: str, visible: bool = False) -> JABElement:
+        """
+        Find an JABElement given a description locator.
+        """
+        if value == self.root_element.description:
+            return self.root_element
+        else:
+            return self.root_element.find_element_by_description(value=value, visible=visible)
+
     def find_element_by_role(self, value: str, visible: bool = False) -> JABElement:
         """
         Find an JABElement given a role locator.
@@ -332,6 +340,7 @@ class JABDriver(object):
         """
         dict_find = {
             By.NAME: self.find_element_by_name,
+            By.DESCRIPTION: self.find_element_by_description,
             By.ROLE: self.find_element_by_role,
             By.STATES: self.find_element_by_states,
             By.OBJECT_DEPTH: self.find_element_by_object_depth,
@@ -340,7 +349,7 @@ class JABDriver(object):
             By.XPATH: self.find_element_by_xpath,
         }
         if by not in dict_find.keys():
-            raise JABException("incorrect by strategy '{}'".format(by))
+            raise JABException(f"incorrect by strategy '{by}'")
         return dict_find[by](value=value, visible=visible)
 
     def find_elements_by_name(
@@ -349,7 +358,7 @@ class JABDriver(object):
         """
         Find list of JABElement given a name locator.
         """
-        jabelements = list()
+        jabelements = []
         if value == self.root_element.name:
             jabelements.append(self.root_element)
         jabelements.extend(
@@ -357,13 +366,27 @@ class JABDriver(object):
         )
         return jabelements
 
+    def find_elements_by_description(
+        self, value: str, visible: bool = False
+    ) -> list[JABElement]:
+        """
+        Find list of JABElement given a description locator.
+        """
+        jabelements = []
+        if value == self.root_element.description:
+            jabelements.append(self.root_element)
+        jabelements.extend(
+            self.root_element.find_elements_by_description(value=value, visible=visible)
+        )
+        return jabelements
+
     def find_elements_by_role(
         self, value: str, visible: bool = False
     ) -> list[JABElement]:
         """
         Find list of JABElement given a role locator.
         """
-        jabelements = list()
+        jabelements = []
         if value == self.root_element.role:
             jabelements.append(self.root_element)
         jabelements.extend(
@@ -377,7 +400,7 @@ class JABDriver(object):
         """
         Find list of JABElement given a states locator.
         """
-        jabelements = list()
+        jabelements = []
         if value == self.root_element.states:
             jabelements.append(self.root_element)
         jabelements.extend(
@@ -391,7 +414,7 @@ class JABDriver(object):
         """
         Find list of JABElement given a object depth locator.
         """
-        jabelements = list()
+        jabelements = []
         if value == self.root_element.object_depth:
             jabelements.append(self.root_element)
         jabelements.extend(
@@ -407,7 +430,7 @@ class JABDriver(object):
         """
         Find list of JABElement given a children count locator.
         """
-        jabelements = list()
+        jabelements = []
         if value == self.root_element.children_count:
             jabelements.append(self.root_element)
         jabelements.extend(
@@ -423,7 +446,7 @@ class JABDriver(object):
         """
         Find list of JABElement given a index in parent locator.
         """
-        jabelements = list()
+        jabelements = []
         if value == self.root_element.index_in_parent:
             jabelements.append(self.root_element)
         jabelements.extend(
@@ -449,6 +472,7 @@ class JABDriver(object):
         """
         dict_finds = {
             By.NAME: self.find_elements_by_name,
+            By.DESCRIPTION: self.find_elements_by_description,
             By.ROLE: self.find_elements_by_role,
             By.STATES: self.find_elements_by_states,
             By.OBJECT_DEPTH: self.find_elements_by_object_depth,
@@ -457,7 +481,7 @@ class JABDriver(object):
             By.XPATH: self.find_elements_by_xpath,
         }
         if by not in dict_finds.keys():
-            raise JABException("incorrect by strategy '{}'".format(by))
+            raise JABException(f"incorrect by strategy '{by}'")
         return dict_finds[by](value=value, visible=visible)
 
     def maximize_window(self):
@@ -486,8 +510,7 @@ class JABDriver(object):
                     f"JABElement with locator '{by}' '{value}' does not found in {timeout} seconds"
                 )
             try:
-                jabelement = self.find_element(by=by, value=value)
-                return jabelement
+                return self.find_element(by=by, value=value)
             except JABException:
                 log_out = f"JABElement with locator '{by}' '{value}' does not found"
                 if self.latest_log != log_out:
@@ -524,7 +547,7 @@ class JABDriver(object):
         y = bounds.get("y")
         width = bounds.get("width")
         height = bounds.get("height")
-        im = ImageGrab.grab(
+        return ImageGrab.grab(
             bbox=(
                 x,
                 y,
@@ -534,7 +557,6 @@ class JABDriver(object):
             include_layered_windows=False,
             all_screens=True,
         )
-        return im
 
     def set_window_size(self, width, height):
         """
