@@ -4,7 +4,7 @@ from pyjab.common.textreader import TextReader
 import re
 from ctypes import Array, byref, CDLL, c_char, c_long, create_string_buffer
 from ctypes.wintypes import HWND
-from typing import Any, Generator
+from typing import Any, Generator, Optional, Union
 from PIL import Image, ImageGrab
 from pyjab.common.by import By
 from pyjab.common.exceptions import JABException
@@ -18,7 +18,7 @@ from pyjab.accessibleinfo import (
     AccessibleTableCellInfo,
     AccessibleTableInfo,
     AccessibleTextInfo,
-    VisibleChildenInfo,
+    VisibleChildrenInfo,
 )
 
 
@@ -137,7 +137,7 @@ class JABElement(object):
 
     @property
     def accessible_interfaces(self) -> bool:
-        # TODO: need handle acc iterface
+        # TODO: need handle acc interface
         return False
 
     @property
@@ -158,7 +158,6 @@ class JABElement(object):
     @property
     def table(self) -> dict:
         if self.role_en_us == "table":
-            tb = {}
             info = self._get_accessible_table_info()
             tb = {
                 "row_count": info.rowCount,
@@ -199,11 +198,10 @@ class JABElement(object):
         Yields:
             Generator: Generator of all child jab elements from this parent jab element.
         """
-        jabelement = (
-            jabelement
-            if jabelement
-            else JABElement(self.bridge, self.hwnd, self.vmid, self.accessible_context)
+        jabelement = jabelement or JABElement(
+            self.bridge, self.hwnd, self.vmid, self.accessible_context
         )
+
         for jabelement in self._generate_childs_from_element(
             jabelement=jabelement, visible=visible
         ):
@@ -227,11 +225,10 @@ class JABElement(object):
         Yields:
             Generator: Generator of child jab elements from this parent jab element.
         """
-        jabelement = (
-            jabelement
-            if jabelement
-            else JABElement(self.bridge, self.hwnd, self.vmid, self.accessible_context)
+        jabelement = jabelement or JABElement(
+            self.bridge, self.hwnd, self.vmid, self.accessible_context
         )
+
         if visible:
             children_count = self._get_visible_children_count(
                 jabelement.accessible_context
@@ -249,10 +246,9 @@ class JABElement(object):
                 child_acc = jabelement.bridge.getAccessibleChildFromContext(
                     jabelement.vmid, jabelement.accessible_context, index
                 )
-                child_element = JABElement(
+                yield JABElement(
                     jabelement.bridge, jabelement.hwnd, jabelement.vmid, child_acc
                 )
-                yield child_element
 
     # JAB apis
     def release_jabelement(self, jabelement: JABElement = None) -> None:
@@ -275,17 +271,13 @@ class JABElement(object):
 
     def _request_focus(self, accessible_context: JOBJECT64 = None) -> None:
         """Request focus for a component. Returns whether successful."""
-        accessible_context = (
-            accessible_context if accessible_context else self.accessible_context
-        )
+        accessible_context = accessible_context or self.accessible_context
         self.bridge.requestFocus(self.vmid, accessible_context)
 
     def _get_accessible_selection_from_context(
         self, accessible_context: JOBJECT64 = None
     ) -> JOBJECT64:
-        accessible_context = (
-            accessible_context if accessible_context else self.accessible_context
-        )
+        accessible_context = accessible_context or self.accessible_context
         return self.bridge.getAccessibleSelectionFromContext(
             self.vmid, accessible_context, 0
         )
@@ -293,9 +285,7 @@ class JABElement(object):
     def _add_accessible_selection_from_context(
         self, index: int, accessible_context: JOBJECT64 = None
     ) -> None:
-        accessible_context = (
-            accessible_context if accessible_context else self.accessible_context
-        )
+        accessible_context = accessible_context or self.accessible_context
         self.bridge.addAccessibleSelectionFromContext(
             self.vmid, accessible_context, index
         )
@@ -303,9 +293,7 @@ class JABElement(object):
     def _clear_accessible_selection_from_context(
         self, accessible_context: JOBJECT64
     ) -> None:
-        accessible_context = (
-            accessible_context if accessible_context else self.accessible_context
-        )
+        accessible_context = accessible_context or self.accessible_context
         self.bridge.clearAccessibleSelectionFromContext(self.vmid, accessible_context)
 
     def _is_same_object(self, obj1: JOBJECT64, obj2: JOBJECT64) -> bool:
@@ -334,9 +322,7 @@ class JABElement(object):
         Returns:
             JOBJECT64: Top level object.
         """
-        accessible_context = (
-            accessible_context if accessible_context else self.accessible_context
-        )
+        accessible_context = accessible_context or self.accessible_context
         top_object = self.bridge.getTopLevelObject(self.vmid, accessible_context)
         if top_object == 0:
             raise JABException(self.int_func_err_msg.format("getTopLevelObject"))
@@ -353,9 +339,7 @@ class JABElement(object):
         Returns:
             JOBJECT64: Parent Accessible Context.
         """
-        accessible_context = (
-            accessible_context if accessible_context else self.accessible_context
-        )
+        accessible_context = accessible_context or self.accessible_context
         return self.bridge.getAccessibleParentFromContext(self.vmid, accessible_context)
 
     def _get_accessible_context_info(
@@ -373,9 +357,7 @@ class JABElement(object):
             AccessibleContextInfo: Accessible Context Info.
         """
         info = AccessibleContextInfo()
-        accessible_context = (
-            accessible_context if accessible_context else self.accessible_context
-        )
+        accessible_context = accessible_context or self.accessible_context
         result = self.bridge.getAccessibleContextInfo(
             self.vmid, accessible_context, byref(info)
         )
@@ -397,9 +379,7 @@ class JABElement(object):
         Returns:
             int: Object depth.
         """
-        accessible_context = (
-            accessible_context if accessible_context else self.accessible_context
-        )
+        accessible_context = accessible_context or self.accessible_context
         object_depth = self.bridge.getObjectDepth(self.vmid, accessible_context)
         if object_depth == -1:
             raise JABException(self.int_func_err_msg.format("getObjectDepth"))
@@ -409,9 +389,7 @@ class JABElement(object):
         self, accessible_context: JOBJECT64 = None
     ) -> AccessibleTextInfo:
         info = AccessibleTextInfo()
-        accessible_context = (
-            accessible_context if accessible_context else self.accessible_context
-        )
+        accessible_context = accessible_context or self.accessible_context
         result = self.bridge.getAccessibleTextInfo(
             self.vmid, accessible_context, byref(info), 0, 0
         )
@@ -427,9 +405,7 @@ class JABElement(object):
         length: int,
         accessible_context: JOBJECT64 = None,
     ) -> None:
-        accessible_context = (
-            accessible_context if accessible_context else self.accessible_context
-        )
+        accessible_context = accessible_context or self.accessible_context
         result = self.bridge.getAccessibleTextRange(
             self.vmid, accessible_context, start, end, text, length
         )
@@ -452,9 +428,7 @@ class JABElement(object):
             AccessibleTableInfo: Accessible Table Info.
         """
         info = AccessibleTableInfo()
-        accessible_context = (
-            accessible_context if accessible_context else self.accessible_context
-        )
+        accessible_context = accessible_context or self.accessible_context
         result = self.bridge.getAccessibleTableInfo(
             self.vmid, accessible_context, byref(info)
         )
@@ -477,9 +451,7 @@ class JABElement(object):
             AccessibleTableInfo: Accessible Table Info.
         """
         info = AccessibleTableInfo()
-        accessible_context = (
-            accessible_context if accessible_context else self.accessible_context
-        )
+        accessible_context = accessible_context or self.accessible_context
         result = self.bridge.getAccessibleTableRowHeader(
             self.vmid, accessible_context, byref(info)
         )
@@ -504,9 +476,7 @@ class JABElement(object):
             AccessibleTableInfo: Accessible Table Info.
         """
         info = AccessibleTableInfo()
-        accessible_context = (
-            accessible_context if accessible_context else self.accessible_context
-        )
+        accessible_context = accessible_context or self.accessible_context
         result = self.bridge.getAccessibleTableColumnHeader(
             self.vmid, accessible_context, byref(info)
         )
@@ -527,9 +497,7 @@ class JABElement(object):
         Returns:
             int: Accessible table row selection count.
         """
-        accessible_context = (
-            accessible_context if accessible_context else self.accessible_context
-        )
+        accessible_context = accessible_context or self.accessible_context
         return self.bridge.getAccessibleTableRowSelectionCount(
             self.vmid, accessible_context
         )
@@ -545,9 +513,7 @@ class JABElement(object):
         Returns:
             int: Accessible table column selection count.
         """
-        accessible_context = (
-            accessible_context if accessible_context else self.accessible_context
-        )
+        accessible_context = accessible_context or self.accessible_context
         return self.bridge.getAccessibleTableColumnSelectionCount(
             self.vmid, accessible_context
         )
@@ -569,9 +535,7 @@ class JABElement(object):
             AccessibleTableCellInfo: Accessible Table Cell Info.
         """
         info = AccessibleTableCellInfo()
-        accessible_context = (
-            accessible_context if accessible_context else self.accessible_context
-        )
+        accessible_context = accessible_context or self.accessible_context
         result = self.bridge.getAccessibleTableCellInfo(
             self.vmid, accessible_context, row, column, byref(info)
         )
@@ -590,9 +554,7 @@ class JABElement(object):
         Returns:
             int: [description]
         """
-        accessible_context = (
-            accessible_context if accessible_context else self.accessible_context
-        )
+        accessible_context = accessible_context or self.accessible_context
         result = self.bridge.getVisibleChildrenCount(self.vmid, accessible_context)
         if result == -1:
             raise JABException(self.int_func_err_msg.format("getVisibleChildrenCount"))
@@ -600,11 +562,9 @@ class JABElement(object):
 
     def _get_visible_children(
         self, accessible_context: JOBJECT64 = None
-    ) -> VisibleChildenInfo:
-        info = VisibleChildenInfo()
-        accessible_context = (
-            accessible_context if accessible_context else self.accessible_context
-        )
+    ) -> VisibleChildrenInfo:
+        info = VisibleChildrenInfo()
+        accessible_context = accessible_context or self.accessible_context
         result = self.bridge.getVisibleChildren(
             self.vmid, accessible_context, 0, byref(info)
         )
@@ -720,7 +680,7 @@ class JABElement(object):
         """
         if self.role_en_us != "scroll bar":
             raise JABException("JABElement is not 'scroll bar'")
-        is_horizontal = True if "horizontal" in self.states_en_us else False
+        is_horizontal = "horizontal" in self.states_en_us
         x = self.bounds["x"]
         y = self.bounds["y"]
         height = self.bounds["height"]
@@ -730,16 +690,13 @@ class JABElement(object):
         if to_bottom and is_horizontal:
             x = x + width - height - 5
             y = y + height / 2
-        # vertical scroll to bottom
-        elif to_bottom is True and is_horizontal is False:
+        elif to_bottom:
             x = x + width / 2
             y = y + height - width - 5
-        # horizontal scroll to top(left)
-        elif to_bottom is False and is_horizontal is True:
+        elif is_horizontal:
             x = x + height + 5
             y = y + height / 2
-        # vertical scroll to top
-        elif to_bottom is False and is_horizontal is False:
+        else:
             x = x + width / 2
             y = y + width + 5
         self.win32_utils._click_mouse(x=int(x), y=int(y), hold=hold)
@@ -758,7 +715,7 @@ class JABElement(object):
         """
         if self.role_en_us != "slider":
             raise JABException("JABElement is not 'slider'")
-        is_horizontal = True if "horizontal" in self.states_en_us else False
+        is_horizontal = "horizontal" in self.states_en_us
         x = self.bounds["x"]
         y = self.bounds["y"]
         height = self.bounds["height"]
@@ -768,15 +725,12 @@ class JABElement(object):
         if to_bottom and is_horizontal:
             x = x + width - 5
             y = y + height / 2
-        # vertical slide to bottom
-        elif to_bottom is True and is_horizontal is False:
+        elif to_bottom:
             x = x + width / 2
             y = y + height - 5
-        # horizontal slide to top(left)
-        elif to_bottom is False and is_horizontal is True:
+        elif is_horizontal:
             y = y + height / 2
-        # vertical slide to top
-        elif to_bottom is False and is_horizontal is False:
+        else:
             x = x + width / 2
         self.win32_utils._click_mouse(x=int(x), y=int(y), hold=hold)
 
@@ -817,8 +771,11 @@ class JABElement(object):
     ) -> None:
         try:
             item = parent.find_element_by_name(value=option)
-        except JABException:
-            raise JABException(f"{parent.role_en_us} option '{option}' does not found")
+        except JABException as e:
+            raise JABException(
+                f"{parent.role_en_us} option '{option}' does not found"
+            ) from e
+
         self._add_accessible_selection_from_context(
             item.index_in_parent, parent.accessible_context
         )
@@ -913,7 +870,7 @@ class JABElement(object):
         self._do_accessible_action(action=action)
 
     def expand(self, simulate: bool = False) -> None:
-        if "expandable" not in self._states_en_us:
+        if "expandable" not in self.states_en_us:
             raise JABException("JABElement does not support 'expand'")
         if simulate:
             self.click(simulate=True)
@@ -991,6 +948,21 @@ class JABElement(object):
         """
         return self.find_element(by=By.NAME, value=value, visible=visible)
 
+    def find_element_by_description(
+        self, value: str, visible: bool = False
+    ) -> JABElement:
+        """find child JABElement by description
+
+        Args:
+            value (str): Locator of JABElement need to find.
+            visible (bool, optional): The switch for find only visible child jab element or not.
+            Defaults to False to find available child element.
+
+        Returns:
+            JABElement: The JABElement find by locator
+        """
+        return self.find_element(by=By.DESCRIPTION, value=value, visible=visible)
+
     def find_element_by_role(self, value: str, visible: bool = False) -> JABElement:
         """find child JABElement by role
 
@@ -1004,7 +976,7 @@ class JABElement(object):
         """
         return self.find_element(by=By.ROLE, value=value, visible=visible)
 
-    def find_element_by_states(self, value: list, visible: bool = False) -> JABElement:
+    def find_element_by_states(self, value: Union[list, str], visible: bool = False) -> JABElement:
         """find child JABElement by states
 
         Args:
@@ -1075,13 +1047,50 @@ class JABElement(object):
         if attr_val[0] in ["'", '"'] and attr_val[-1] in ["'", '"']:
             attr_val = attr_val[1:-1]
         pattern = re.compile("^contains\([\"'](.*?)[\"']\)")
-        content = pattern.findall(attr_val)
-        if content:
+        if content := pattern.findall(attr_val):
             return content[0] in jabelement.name
         else:
             return attr_val == jabelement.name
 
-    def _is_match_attr_states(self, attr_val: str, jabelement: JABElement) -> bool:
+    def _is_match_attr_description(self, attr_val: str, jabelement: JABElement) -> bool:
+        """Return the attribute value is matched or not by description.
+
+        Args:
+            attr_val (str): Attribute description value
+            jabelement (JABElement): The JABElement
+
+        Returns:
+            bool: True for attribute matched False for not
+        """
+        if attr_val[0] in ["'", '"'] and attr_val[-1] in ["'", '"']:
+            attr_val = attr_val[1:-1]
+        pattern = re.compile("^contains\([\"'](.*?)[\"']\)")
+        if content := pattern.findall(attr_val):
+            return content[0] in jabelement.description
+        else:
+            return attr_val == jabelement.description
+
+    @staticmethod
+    def _is_match_attr_role(attr_val: str, jabelement: JABElement) -> bool:
+        """Return the attribute value is matched or not by role.
+
+        Args:
+            attr_val (str): Attribute description value
+            jabelement (JABElement): The JABElement
+
+        Returns:
+            bool: True for attribute matched False for not
+        """
+        if attr_val[0] in ["'", '"'] and attr_val[-1] in ["'", '"']:
+            attr_val = attr_val[1:-1]
+        pattern = re.compile("^contains\([\"'](.*?)[\"']\)")
+        if content := pattern.findall(attr_val):
+            return content[0] in jabelement.role
+        else:
+            return attr_val == jabelement.role
+
+    @staticmethod
+    def _is_match_attr_states(attr_val: str, jabelement: JABElement) -> bool:
         """Return the attribute value is matched or not by states.
 
         Args:
@@ -1094,11 +1103,8 @@ class JABElement(object):
         if attr_val[0] in ["'", '"'] and attr_val[-1] in ["'", '"']:
             attr_val = attr_val[1:-1]
         pattern = re.compile("^contains\([\"'](.*?)[\"']\)")
-        content = pattern.findall(attr_val)
-        if content:
-            return all(
-                [stat in jabelement.states_en_us for stat in content[0].split(",")]
-            )
+        if content := pattern.findall(attr_val):
+            return all(stat in jabelement.states_en_us for stat in content[0].split(","))
         else:
             return set(attr_val.split(",")) == set(jabelement.states_en_us)
 
@@ -1161,6 +1167,8 @@ class JABElement(object):
         """
         dict_attribute = {
             "name": self._is_match_attr_name,
+            "role": self._is_match_attr_role,
+            "description": self._is_match_attr_description,
             "states": self._is_match_attr_states,
             "objectdepth": self._is_match_attr_objectdepth,
             "childrencount": self._is_match_attr_childrencount,
@@ -1170,7 +1178,7 @@ class JABElement(object):
             name = attribute.get("name")
             value = attribute.get("value")
             if name not in dict_attribute.keys():
-                raise JABException("incorrect attribute name '{}'".format(name))
+                raise JABException(f"incorrect attribute name '{name}'")
             if not dict_attribute[name](value, jabelement):
                 return False
         return True
@@ -1184,23 +1192,15 @@ class JABElement(object):
         Returns:
             JABElement: Node JABElement
         """
-        jabelement = (
-            jabelement
-            if jabelement
-            else JABElement(self.bridge, self.hwnd, self.vmid, self.accessible_context)
-        )
+        jabelement = jabelement or JABElement(self.bridge, self.hwnd, self.vmid, self.accessible_context)
         is_same = self._is_same_object(
             self.accessible_context, jabelement.accessible_context
         )
-        if is_same:
-            top_object = self._get_top_level_object(self.accessible_context)
-            is_top_level = self._is_same_object(self.accessible_context, top_object)
-            if is_top_level:
-                return jabelement
-            else:
-                return self.parent
-        else:
+        if not is_same:
             return jabelement
+        top_object = self._get_top_level_object(self.accessible_context)
+        is_top_level = self._is_same_object(self.accessible_context, top_object)
+        return jabelement if is_top_level else self.parent
 
     def _get_element_by_node(
         self,
@@ -1238,20 +1238,16 @@ class JABElement(object):
         node_role = node_info.get("role")
         node_attributes = node_info.get("attributes")
         jabelement = self._get_node_element(jabelement)
-        child_jabelement = None
         for _jabelement in dict_gen[level](jabelement=jabelement, visible=visible):
             if node_role not in ["*", _jabelement.role_en_us]:
                 self.release_jabelement(_jabelement)
                 continue
             if self._is_match_attributes(node_attributes, _jabelement):
-                child_jabelement = _jabelement
-                break
+                return _jabelement
             self.release_jabelement(_jabelement)
-        else:
-            raise JABException(
-                "no JABElement found in level {} with node '{}'".format(level, node)
-            )
-        return child_jabelement
+        raise JABException(
+            f"no JABElement found in level {level} with node '{node}'"
+        )
 
     def find_element_by_xpath(self, value: str, visible: bool = False) -> JABElement:
         """find child JABElement by xpath
@@ -1302,6 +1298,7 @@ class JABElement(object):
         """
         if by not in [
             By.NAME,
+            By.DESCRIPTION,
             By.ROLE,
             By.STATES,
             By.OBJECT_DEPTH,
@@ -1309,32 +1306,16 @@ class JABElement(object):
             By.INDEX_IN_PARENT,
             By.XPATH,
         ]:
-            raise JABException("incorrect by strategy '{}'".format(by))
+            raise JABException(f"incorrect by strategy '{by}'")
         if by == By.XPATH:
             self.find_element_by_xpath(value=value, visible=visible)
-        located_element = None
         for jabelement in self._generate_all_childs(visible=visible):
-            is_matched = (
-                (value is None)
-                or (by == By.NAME and jabelement.name == value)
-                or (by == By.ROLE and jabelement.role_en_us == value)
-                or (by == By.STATES and set(jabelement.states_en_us) == set(value))
-                or (by == By.OBJECT_DEPTH and jabelement.object_depth == int(value))
-                or (by == By.CHILDREN_COUNT and jabelement.children_count == int(value))
-                or (
-                    by == By.INDEX_IN_PARENT
-                    and jabelement.index_in_parent == int(value)
-                )
-            )
-            if is_matched:
-                located_element = jabelement
-                break
+            if self._is_element_matched(by=by, value=value, jabelement=jabelement):
+                return jabelement
             self.release_jabelement(jabelement)
-        else:
-            raise JABException(
-                "jab element not found by '{}' with locator '{}'".format(by, value)
-            )
-        return located_element
+        raise JABException(
+            f"jab element not found by '{by}' with locator '{value}'"
+        )
 
     def find_elements_by_name(
         self, value: str, visible: bool = False
@@ -1351,6 +1332,21 @@ class JABElement(object):
         """
         return self.find_elements(by=By.NAME, value=value, visible=visible)
 
+    def find_elements_by_description(
+        self, value: str, visible: bool = False
+    ) -> list[JABElement]:
+        """Find list of child JABElement by description
+
+        Args:
+            value (str): Locator of list JABElement need to find.
+            visible (bool, optional): The switch for find only visible child jab elements or not.
+            Defaults to False to find all child elements.
+
+        Returns:
+            list[JABElement]: List of JABElement find by locator
+        """
+        return self.find_elements(by=By.DESCRIPTION, value=value, visible=visible)
+
     def find_elements_by_role(
         self, value: str, visible: bool = False
     ) -> list[JABElement]:
@@ -1367,7 +1363,7 @@ class JABElement(object):
         return self.find_elements(by=By.ROLE, value=value, visible=visible)
 
     def find_elements_by_states(
-        self, value: list, visible: bool = False
+        self, value: Union[list, str], visible: bool = False
     ) -> list[JABElement]:
         """Find list of child JABElement by states
 
@@ -1461,7 +1457,7 @@ class JABElement(object):
         node_role = node_info.get("role")
         node_attributes = node_info.get("attributes")
         jabelement = self._get_node_element(jabelement)
-        jabelements = list()
+        jabelements = []
         for _jabelement in dict_gen[level](jabelement=jabelement, visible=visible):
             if node_role not in ["*", _jabelement.role_en_us]:
                 self.release_jabelement(_jabelement)
@@ -1496,8 +1492,8 @@ class JABElement(object):
             level: str,
             parent_jabelements: list[JABElement],
             visible: bool = False,
-        ) -> list(JABElement):
-            child_jabelements = list()
+        ) -> list[JABElement]:
+            child_jabelements = []
             for parent_jabelement in parent_jabelements:
                 jabelements = self._get_elements_by_node(
                     node=node,
@@ -1521,7 +1517,7 @@ class JABElement(object):
         return jabelements
 
     def find_elements(
-        self, by: str = By.NAME, value: str = None, visible: bool = False
+        self, by: str = By.NAME, value: Union[list, str, int] = None, visible: bool = False
     ) -> list[JABElement]:
         """Find list of JABElement given a By strategy and locator.
 
@@ -1537,6 +1533,7 @@ class JABElement(object):
         """
         if by not in [
             By.NAME,
+            By.DESCRIPTION,
             By.ROLE,
             By.STATES,
             By.OBJECT_DEPTH,
@@ -1544,33 +1541,39 @@ class JABElement(object):
             By.INDEX_IN_PARENT,
             By.XPATH,
         ]:
-            raise JABException("incorrect by strategy '{}'".format(by))
+            raise JABException(f"incorrect by strategy '{by}'")
         if by == By.XPATH:
             self.find_elements_by_xpath(value=value, visible=visible)
-        jabelements = list()
+        jabelements = []
         for jabelement in self._generate_all_childs(visible=visible):
-            is_matched = (
-                (value is None)
-                or (by == By.NAME and jabelement.name == value)
-                or (by == By.ROLE and jabelement.role_en_us == value)
-                or (by == By.STATES and set(jabelement.states_en_us) == set(value))
-                or (by == By.OBJECT_DEPTH and jabelement.object_depth == int(value))
-                or (by == By.CHILDREN_COUNT and jabelement.children_count == int(value))
-                or (
-                    by == By.INDEX_IN_PARENT
-                    and jabelement.index_in_parent == int(value)
-                )
-            )
-            if is_matched:
+            if self._is_element_matched(by=by, value=value, jabelement=jabelement):
                 jabelements.append(jabelement)
                 continue
             self.release_jabelement(jabelement)
         if not jabelements:
             raise JABException(
-                "no JABElement found by '{}' with locator '{}'".format(by, value)
+                f"no JABElement found by '{by}' with locator '{value}'"
             )
         return jabelements
 
+    @staticmethod
+    def _is_element_matched(jabelement: JABElement, by: str, value: Optional[str]):
+        return any(
+                [
+                    value is None,
+                    by == By.NAME and jabelement.name == value,
+                    by == By.ROLE and jabelement.role == value,
+                    by == By.DESCRIPTION and jabelement.description == value,
+                    by == By.STATES and set(jabelement.states_en_us) == set(value),
+                    by == By.OBJECT_DEPTH
+                    and jabelement.object_depth == int(value),
+                    by == By.CHILDREN_COUNT
+                    and jabelement.children_count == int(value),
+                    by == By.INDEX_IN_PARENT
+                    and jabelement.index_in_parent == int(value),
+                ]
+            )
+
     @property
     def size(self) -> dict:
         """The size of the element."""
@@ -1609,7 +1612,7 @@ class JABElement(object):
         y = self.bounds.get("y")
         width = self.bounds.get("width")
         height = self.bounds.get("height")
-        im = ImageGrab.grab(
+        return ImageGrab.grab(
             bbox=(
                 x,
                 y,
@@ -1619,7 +1622,6 @@ class JABElement(object):
             include_layered_windows=False,
             all_screens=True,
         )
-        return im
 
     @property
     def parent(self):
@@ -1659,7 +1661,7 @@ class JABElement(object):
 
     def get_element_information(self) -> dict:
         """Get dict information of current JABElement.
-        
+
         Notice:
             This dict of component value will NOT update after property changes.
 
